const data = [
  {
    age: 20,
    gender: 'Female',
    maritalStatus: 'Single',
    occupation: 'Student',
    monthlyIncome: 'No Income',
    education: 'Post Grad',
    familySize: 4,
  },
  {
    age: 24,
    gender: 'Female',
    maritalStatus: 'Single',
    occupation: 'Student',
    monthlyIncome: 'Below Rs.10000',
    education: 'Graduate',
    familySize: 3,
  },
  {
    age: 22,
    gender: 'Male',
    maritalStatus: 'Single',
    occupation: 'Student',
    monthlyIncome: 'Below Rs.10000',
    education: 'Post Grad',
    familySize: 3,
  },
  {
    age: 22,
    gender: 'Female',
    maritalStatus: 'Single',
    occupation: 'Student',
    monthlyIncome: 'No Income',
    education: 'Graduate',
    familySize: 6,
  },
  {
    age: 22,
    gender: 'Male',
    maritalStatus: 'Single',
    occupation: 'Student',
    monthlyIncome: 'Below Rs.10000',
    education: 'Post Grad',
    familySize: 4,
  },
];

// Set dimensions and margins for the graph
const margin = { top: 20, right: 20, bottom: 30, left: 40 },
  width = 960 - margin.left - margin.right,
  height = 500 - margin.top - margin.bottom;

// Append the svg object to the body of the page
const svg = d3
  .select('body')
  .append('svg')
  .attr('width', width + margin.left + margin.right)
  .attr('height', height + margin.top + margin.bottom)
  .append('g')
  .attr(
    'transform',
    `translate(${margin.left},${margin.top})`,
  );

// Set up the scales
const x = d3.scaleBand().range([0, width]).padding(0.1);
const y = d3.scaleLinear().range([height, 0]);

// Set up the stack keys (the income levels)
const stackKeys = ['No Income', 'Below Rs.10000'];

// Process the data to stack it
const series = d3
  .stack()
  .keys(stackKeys)
  .value((d, key) => {
    return key === 'No Income'
      ? d.monthlyIncome === 'No Income'
        ? 1
        : 0
      : d.monthlyIncome === 'Below Rs.10000'
        ? 1
        : 0;
  })(data);

// Set domains
x.domain(data.map((d) => d.age + d.gender)); // Unique identifier for each bar
y.domain([
  0,
  d3.max(series, (serie) => d3.max(serie, (d) => d[1])),
]).nice();

// Add the bars
svg
  .selectAll('.serie')
  .data(series)
  .enter()
  .append('g')
  .attr('class', 'serie')
  .attr('fill', (d) => {
    // Color the bars based on income level
    return d.key === 'No Income'
      ? 'steelblue'
      : 'darkorange';
  })
  .selectAll('rect')
  .data((d) => d)
  .enter()
  .append('rect')
  .attr('x', (d) => x(d.data.age + d.data.gender))
  .attr('y', (d) => y(d[1]))
  .attr('height', (d) => y(d[0]) - y(d[1]))
  .attr('width', x.bandwidth());

// Add the X Axis
svg
  .append('g')
  .attr('transform', `translate(0,${height})`)
  .call(d3.axisBottom(x));

// Add the Y Axis
svg.append('g').call(d3.axisLeft(y));
